__version__ = "0.2.8"
__git_commiter_name__ = "Arnon Yaari"
__git_commiter_email__ = "arnony@infinidat.com"
__git_branch__ = '(HEAD detached at v0.2.8)'
__git_remote_tracking_branch__ = '(No remote tracking)'
__git_remote_url__ = '(Not remote tracking)'
__git_head_hash__ = 'eebe605b5061f94e090aeb0f88f5053a7c0fc828'
__git_head_subject__ = 'Finished Release v0.2.8'
__git_head_message__ = ''
__git_dirty_diff__ = ''
__git_commit_date__ = '2016-12-18 14:33:57'



from __future__ import print_function

#pylint: disable-msg=E1101
def print_records():
    from .interface import get_product_info, get_system_info, get_version_ex
    from .structures import OSVersionEx, SystemInfo

    version = get_version_ex()
    system_info = get_system_info()
    try:
        product_info = get_product_info(version.major_version, version.minor_version,
                                    version.service_pack_major, version.service_pack_minor)
    except:  # pylint: disable-msg=W0702
        # product_info not available on Windows 2003, XP
        product_info = None
    print("OSVersionEx = %s" % repr(OSVersionEx.write_to_string(version)))
    print("SystemInfo = %s" % repr(SystemInfo.write_to_string(system_info)))
    print("ProductInfo = %s" % repr(product_info))
